==> tbb-dev-cpp-2021.8.0.package.tar.zst: usr/lib64/cmake/TBB/TBBTargets-gentoo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Gentoo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "TBB::tbb" for configuration "Gentoo"
set_property(TARGET TBB::tbb APPEND PROPERTY IMPORTED_CONFIGURATIONS GENTOO)
set_target_properties(TBB::tbb PROPERTIES
  IMPORTED_LOCATION_GENTOO "${_IMPORT_PREFIX}/lib64/libtbb.so.12.8"
  IMPORTED_SONAME_GENTOO "libtbb.so.12"
  )

list(APPEND _IMPORT_CHECK_TARGETS TBB::tbb )
list(APPEND _IMPORT_CHECK_FILES_FOR_TBB::tbb "${_IMPORT_PREFIX}/lib64/libtbb.so.12.8" )

# Import target "TBB::tbbmalloc" for configuration "Gentoo"
set_property(TARGET TBB::tbbmalloc APPEND PROPERTY IMPORTED_CONFIGURATIONS GENTOO)
set_target_properties(TBB::tbbmalloc PROPERTIES
  IMPORTED_LOCATION_GENTOO "${_IMPORT_PREFIX}/lib64/libtbbmalloc.so.2.8"
  IMPORTED_SONAME_GENTOO "libtbbmalloc.so.2"
  )

list(APPEND _IMPORT_CHECK_TARGETS TBB::tbbmalloc )
list(APPEND _IMPORT_CHECK_FILES_FOR_TBB::tbbmalloc "${_IMPORT_PREFIX}/lib64/libtbbmalloc.so.2.8" )

# Import target "TBB::tbbmalloc_proxy" for configuration "Gentoo"
set_property(TARGET TBB::tbbmalloc_proxy APPEND PROPERTY IMPORTED_CONFIGURATIONS GENTOO)
set_target_properties(TBB::tbbmalloc_proxy PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_GENTOO "TBB::tbbmalloc"
  IMPORTED_LOCATION_GENTOO "${_IMPORT_PREFIX}/lib64/libtbbmalloc_proxy.so.2.8"
  IMPORTED_SONAME_GENTOO "libtbbmalloc_proxy.so.2"
  )

list(APPEND _IMPORT_CHECK_TARGETS TBB::tbbmalloc_proxy )
list(APPEND _IMPORT_CHECK_FILES_FOR_TBB::tbbmalloc_proxy "${_IMPORT_PREFIX}/lib64/libtbbmalloc_proxy.so.2.8" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> tbb-dev-cpp-2021.11.0.package.tar.zst: usr/lib64/cmake/TBB/TBBTargets-gentoo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Gentoo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "TBB::tbb" for configuration "Gentoo"
set_property(TARGET TBB::tbb APPEND PROPERTY IMPORTED_CONFIGURATIONS GENTOO)
set_target_properties(TBB::tbb PROPERTIES
  IMPORTED_LOCATION_GENTOO "${_IMPORT_PREFIX}/lib64/libtbb.so.12.11"
  IMPORTED_SONAME_GENTOO "libtbb.so.12"
  )

list(APPEND _cmake_import_check_targets TBB::tbb )
list(APPEND _cmake_import_check_files_for_TBB::tbb "${_IMPORT_PREFIX}/lib64/libtbb.so.12.11" )

# Import target "TBB::tbbmalloc" for configuration "Gentoo"
set_property(TARGET TBB::tbbmalloc APPEND PROPERTY IMPORTED_CONFIGURATIONS GENTOO)
set_target_properties(TBB::tbbmalloc PROPERTIES
  IMPORTED_LOCATION_GENTOO "${_IMPORT_PREFIX}/lib64/libtbbmalloc.so.2.11"
  IMPORTED_SONAME_GENTOO "libtbbmalloc.so.2"
  )

list(APPEND _cmake_import_check_targets TBB::tbbmalloc )
list(APPEND _cmake_import_check_files_for_TBB::tbbmalloc "${_IMPORT_PREFIX}/lib64/libtbbmalloc.so.2.11" )

# Import target "TBB::tbbmalloc_proxy" for configuration "Gentoo"
set_property(TARGET TBB::tbbmalloc_proxy APPEND PROPERTY IMPORTED_CONFIGURATIONS GENTOO)
set_target_properties(TBB::tbbmalloc_proxy PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_GENTOO "TBB::tbbmalloc"
  IMPORTED_LOCATION_GENTOO "${_IMPORT_PREFIX}/lib64/libtbbmalloc_proxy.so.2.11"
  IMPORTED_SONAME_GENTOO "libtbbmalloc_proxy.so.2"
  )

list(APPEND _cmake_import_check_targets TBB::tbbmalloc_proxy )
list(APPEND _cmake_import_check_files_for_TBB::tbbmalloc_proxy "${_IMPORT_PREFIX}/lib64/libtbbmalloc_proxy.so.2.11" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
